Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(164)

Unified Diff: third_party/protobuf/src/google/protobuf/source_context.proto

Issue 2599263002: third_party/protobuf: Update to HEAD (f52e188fe4) (Closed)
Patch Set: Address comments Created 4 years ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: third_party/protobuf/src/google/protobuf/source_context.proto
diff --git a/third_party/protobuf/src/google/protobuf/source_context.proto b/third_party/protobuf/src/google/protobuf/source_context.proto
index d76252ca841edba2598636ef122f264432edce73..f3b2c966811f399fa95fcbf1b2a66911e10ea63a 100644
--- a/third_party/protobuf/src/google/protobuf/source_context.proto
+++ b/third_party/protobuf/src/google/protobuf/source_context.proto
@@ -36,13 +36,13 @@ option csharp_namespace = "Google.Protobuf.WellKnownTypes";
option java_package = "com.google.protobuf";
option java_outer_classname = "SourceContextProto";
option java_multiple_files = true;
-option java_generate_equals_and_hash = true;
option objc_class_prefix = "GPB";
+option go_package = "google.golang.org/genproto/protobuf/source_context;source_context";
// `SourceContext` represents information about the source of a
// protobuf element, like the file in which it is defined.
message SourceContext {
// The path-qualified name of the .proto file that contained the associated
// protobuf element. For example: `"google/protobuf/source.proto"`.
string file_name = 1;
}
@@ -36,13 +36,13 @@ option csharp_namespace = "Google.Protobuf.WellKnownTypes";
message SourceContext {
// The path-qualified name of the .proto file that contained the associated
- // protobuf element. For example: `"google/protobuf/source.proto"`.
+ // protobuf element. For example: `"google/protobuf/source_context.proto"`.
string file_name = 1;
}

Powered by Google App Engine
This is Rietveld 408576698